<?php
/*
	Plugin Name: OT Sermons
	Plugin URI: http://oceanthemes.net/
	Description: Declares a plugin that will create a custom post type displaying sermons.
	Version: 1.0.1
	Author: OceanThemes
	Author URI: http://oceanthemes.net/
	Text Domain: ot-sermons
	Domain Path: /languages
	License: GPLv2 or later
*/

/* UPDATE 
  register_activation_hook is not called when a plugin is updated
  so we need to use the following function 
*/
function ot_sermons_update() {
	load_plugin_textdomain('ot-sermons', FALSE, dirname(plugin_basename(__FILE__)) . '/languages/');
}
add_action('plugins_loaded', 'ot_sermons_update');

add_action( 'init', 'register_ocean_sermons' );
function register_ocean_sermons() {
    /* In Permalink Settings page */	
	$slug = get_option( 'wpse30021_sermons_base' );
    if( ! $slug ) $slug = __( 'sermons', 'ot-sermons' );
	
    $labels = array( 
        'name' => __( 'Sermons', 'ot-sermons' ),
        'singular_name' => $slug, //In Permalink Settings page
        'add_new' => __( 'Add New', 'ot-sermons' ),
        'add_new_item' => __( 'Add New Sermons', 'ot-sermons' ),
        'edit_item' => __( 'Edit Sermons', 'ot-sermons' ),
        'new_item' => __( 'Add New Sermons', 'ot-sermons' ),
		'all_items' => __('All Sermons','ot-sermons'),
        'view_item' => __( 'View Sermons', 'ot-sermons' ),
        'search_items' => __( 'Search Sermons', 'ot-sermons' ),
        'not_found' => __( 'No sermons found..', 'ot-sermons' ),
        'not_found_in_trash' => __( 'No sermons found in Trash', 'ot-sermons' ),
        'parent_item_colon' => __( 'Parent Sermons:', 'ot-sermons' ),
        'menu_name' => __( 'Sermons', 'ot-sermons' ),
    );	

    $args = array( 
        'labels' => $labels,
        'hierarchical' => false,
        'description' => __( 'List Sermons', 'ot-sermons' ),
        'supports' => array( 'title', 'editor', 'thumbnail', 'comments', 'post-formats' ),
        'taxonomies' => array('sermons-category'),
        'public' => true,
        'show_ui' => true,
        'show_in_menu' => true,
        'menu_position' => null,
        'menu_icon' => 'dashicons-book-alt',
        'show_in_nav_menus' => true,
		'show_in_admin_bar'   => true,
        'publicly_queryable' => true,
        'exclude_from_search' => false,
        'has_archive' => true,
        'query_var' => true,
        'can_export' => true,
        'rewrite' => array( 'slug' => $slug ), //In Permalink Settings page
        'capability_type' => 'post'
    );
    register_post_type( 'sermons', $args );
}

add_action( 'init', 'create_sermons_categories_hierarchical_taxonomy', 0 );
//create a custom taxonomy name it Skillss for your posts
function create_sermons_categories_hierarchical_taxonomy() {

	// Add new taxonomy, make it hierarchical like categories
	//first do the translations part for GUI
	$labels = array(
		'name' => __( 'Sermons Categories', 'ot-sermons' ),
		'singular_name' => __( 'Sermons Categories', 'ot-sermons' ),
		'search_items' =>  __( 'Search Sermons Categories','ot-sermons' ),
		'all_items' => __( 'All Sermons Categories','ot-sermons' ),
		'parent_item' => __( 'Parent Sermons Categories','ot-sermons' ),
		'parent_item_colon' => __( 'Parent Sermons Categories:','ot-sermons' ),
		'edit_item' => __( 'Edit Sermons Categories','ot-sermons' ), 
		'update_item' => __( 'Update Sermons Categories','ot-sermons' ),
		'add_new_item' => __( 'Add New Sermons Categories','ot-sermons' ),
		'new_item_name' => __( 'New Sermons Categories Name','ot-sermons' ),
		'menu_name' => __( 'Sermons Categories','ot-sermons' ),
	);     
	// Now register the taxonomy
	register_taxonomy('sermons-category',array('sermons'), array(
		'hierarchical' => true,
		'labels' => $labels,
		'show_ui' => true,
		'show_admin_column' => true,
		'query_var' => true,
		'rewrite' => array( 'slug' => __( 'sermons-category', 'ot-sermons' ) ), 
	));

}

/**
 * Load template file for sermons single
 *
 * @since  1.0.0
 *
 * @param  string $template
 *
 * @return string
 */
add_filter( 'template_include', 'sermons_include_template_function', 1 ); 
function sermons_include_template_function( $template_path ) {
    if ( get_post_type() == 'sermons' ) {
        if ( is_single() ) {
            // checks if the file exists in the theme first,
            // otherwise serve the file from the plugin
            if ( $theme_file = locate_template( array ( 'single-sermons.php' ) ) ) {
                $template_path = $theme_file;
            } else {
                $template_path = plugin_dir_path(__FILE__) . 'template/single-sermons.php';
            }
        }
    }
    return $template_path;
}

// Add to admin_init function
add_filter('manage_edit-sermons_columns', 'add_new_sermons_columns');
function add_new_sermons_columns($sermons_columns) { 
	$new_columns['cb'] = '<input type="checkbox" />'; 	
	$new_columns['featured_image'] = _x('Featured Image', 'ot-sermons');
    $new_columns['title'] = _x('Title', 'ot-sermons');
    $new_columns['author'] = _x('Author', 'ot-sermons');
    $new_columns['sermons-category'] = _x('Sermons Categories', 'ot-sermons');	
	$new_columns['comments'] = '<span class="vers"><div title="Comments" class="comment-grey-bubble"></div></span>';
    $new_columns['date'] = _x('Date', 'ot-sermons');

    return $new_columns;
}

// Add to admin_init function
add_action('manage_sermons_posts_custom_column', 'manage_sermons_columns', 10, 2);
function manage_sermons_columns($column, $post_id) {
    global $post;
    switch ($column) {
        case 'sermons-category':
            $terms = get_the_terms($post_id, 'sermons-category');
            if (!empty($terms)) {
                $out = array();
                foreach ($terms as $term) {
                    $out[] = sprintf('<a href="%s&post_type=sermons">%s</a>', esc_url(add_query_arg(array(
                        'post_type' => $post->post_type,
                        'sermons-category' => $term->slug
                    ), 'edit.php')), esc_html(sanitize_term_field('name', $term->name, $term->term_id, 'sermons-category', 'display')));
                }
                echo join(', ', $out);
            } else {
                _e('No Portfolio Category', 'ot-sermons');
            }
            break;    
        default:
            break;
    } // end switch
}

/**
 * get featured image function
 */
function sermons_featured_image($post_ID) {
	$post_thumbnail_id = get_post_thumbnail_id( $post_ID );
	if ( $post_thumbnail_id ) {		
		return $post_thumbnail_img = wp_get_attachment_image_url( $post_thumbnail_id, 'thumbnail' );
	}
}

/**
 * show featured image in column
 */
function sermons_columns_content($column_name, $post_ID) {
	if ( $column_name == 'featured_image' ) {
		$post_featured_image = get_post_thumbnail_id( $post_ID );
		if ( $post_featured_image != '' ) { 
			echo wp_get_attachment_image( $post_featured_image, 'thumbnail', '', array( "class" => "img-responsive" ) ); 
		}
	}
}
add_action('manage_sermons_posts_custom_column', 'sermons_columns_content', 10, 2);

/**
 * Easy change slug cutom post type name in url to the permalink settings page.
 */
add_action( 'load-options-permalink.php', 'wpse30021_sermons_load_permalinks' );
function wpse30021_sermons_load_permalinks()
{
	if( isset( $_POST['wpse30021_sermons_base'] ) )
	{
		update_option( 'wpse30021_sermons_base', sanitize_title_with_dashes( $_POST['wpse30021_sermons_base'] ) );
	}
	
	// Add a settings field to the permalink page
	add_settings_field( 'wpse30021_sermons_base', __( 'OT Sermons base', 'ot-sermons' ), 'wpse30021_sermons_field_callback', 'permalink', 'optional' );	
}
function wpse30021_sermons_field_callback()
{
	$value = get_option( 'wpse30021_sermons_base' );	
	echo '<input type="text" value="' . esc_attr( $value ) . '" name="wpse30021_sermons_base" id="wpse30021_sermons_base" class="regular-text" />';
}

?>